@@ -52,13 +52,14 @@ bed_cluster <- function(x, max_dist = 0) {
   res <- bed_sort(res)
 
   res <- merge_impl(res, max_dist, collapse = FALSE)
+  res <- tibble::as_tibble(res)
 
-  res <- mutate(res, .id = .id_merge)
+  res <- mutate(res, .id = .data[[".id_merge"]])
   res <- select(res, !!quo(-one_of(".id_merge")))
   res <- ungroup(res)
   res <- mutate(
     res,
-    .id = match(.id, unique(.id))
+    .id = match(.data[[".id"]], unique(.data[[".id"]]))
   )
   res
 }
