@@ -3,8 +3,10 @@
 #' @param x [ivl_df]
 #' @param y [ivl_df]
 #' @param ... extra arguments (not used)
-#'
-#' @note Book-ended intervals are included in coverage calculations.
+#' @param min_overlap minimum overlap in base pairs required for coverage.
+#'   Set to `1` to exclude book-ended intervals (matching bedtools behavior), or
+#'   `0` to include them (legacy valr behavior). The default will change from
+#'   `0` to `1` in a future version.
 #'
 #' @template groups
 #'
@@ -40,10 +42,23 @@
 #' @seealso \url{https://bedtools.readthedocs.io/en/latest/content/tools/coverage.html}
 #'
 #' @export
-bed_coverage <- function(x, y, ...) {
+bed_coverage <- function(x, y, ..., min_overlap = NULL) {
   check_required(x)
   check_required(y)
 
+  # Handle min_overlap deprecation: default to 0 (legacy) but warn
+  if (is.null(min_overlap)) {
+    lifecycle::deprecate_warn(
+      when = "0.8.0",
+      what = "bed_coverage(min_overlap)",
+      details = c(
+        "The default will change from 0 (book-ended intervals overlap) to 1 (strict overlap) in a future version.",
+        "Set `min_overlap = 0L` to keep the legacy behavior, or `min_overlap = 1L` for bedtools-compatible behavior."
+      )
+    )
+    min_overlap <- 0L
+  }
+
   x <- check_interval(x)
   y <- check_interval(y)
 
@@ -71,8 +86,10 @@ bed_coverage <- function(x, y, ...) {
     x,
     y,
     grp_indexes$x,
-    grp_indexes$y
+    grp_indexes$y,
+    min_overlap
   )
+  res <- tibble::as_tibble(res)
 
   # get x ivls from groups not found in y
   mi <- get_missing_ivls(res, x, .id_col)
