@@ -39,7 +39,7 @@ bed_sort <- function(x, by_size = FALSE, by_chrom = FALSE, reverse = FALSE) {
   x <- check_interval(x)
 
   if (by_size) {
-    res <- mutate(x, .size = end - start)
+    res <- mutate(x, .size = .data[["end"]] - .data[["start"]])
 
     if (by_chrom) {
       if (reverse) {
@@ -56,13 +56,13 @@ bed_sort <- function(x, by_size = FALSE, by_chrom = FALSE, reverse = FALSE) {
     }
 
     # remove .size column and groups in result
-    res <- select(res, -.size)
+    res <- select(res, -all_of(".size"))
   } else {
     # sort by coordinate
     if (reverse) {
-      res <- x[order(x$chrom, -x$start, method = "radix"), ]
+      res <- x[order(x$chrom, -x[["start"]], method = "radix"), ]
     } else {
-      res <- x[order(x$chrom, x$start, x$end, method = "radix"), ]
+      res <- x[order(x$chrom, x[["start"]], x[["end"]], method = "radix"), ]
     }
   }
 
