@@ -1,5 +1,11 @@
 vcapply <- function(X, FUN, ..., USE.NAMES = TRUE) {
-  vapply(X = X, FUN = FUN, FUN.VALUE = character(1L), ..., USE.NAMES = USE.NAMES)
+  vapply(
+    X = X,
+    FUN = FUN,
+    FUN.VALUE = character(1L),
+    ...,
+    USE.NAMES = USE.NAMES
+  )
 }
 
 astyle <- function(extra_args = character()) {
@@ -20,10 +26,28 @@ astyle <- function(extra_args = character()) {
     "--align-reference=type"
   )
 
-  src_path <- normalizePath(vcapply(c("../../src", "../../inst/include"), testthat::test_path))
-  src_files <- dir(src_path, "[.](?:cpp|h)$", recursive = TRUE, full.names = TRUE)
-  astyle_files <- grep("(?:RcppExports[.]cpp|static_assert[.]h)", src_files, value = TRUE, invert = TRUE)
-  output <- system2(astyle_cmd, c(astyle_args, astyle_files, extra_args), stdout = TRUE, stderr = TRUE)
+  src_path <- normalizePath(vcapply(
+    c("../../src", "../../inst/include"),
+    testthat::test_path
+  ))
+  src_files <- dir(
+    src_path,
+    "[.](?:cpp|h)$",
+    recursive = TRUE,
+    full.names = TRUE
+  )
+  astyle_files <- grep(
+    "(?:RcppExports[.]cpp|static_assert[.]h)",
+    src_files,
+    value = TRUE,
+    invert = TRUE
+  )
+  output <- system2(
+    astyle_cmd,
+    c(astyle_args, astyle_files, extra_args),
+    stdout = TRUE,
+    stderr = TRUE
+  )
   unchanged <- grepl("^Unchanged", output)
   if (any(!unchanged)) {
     warning(paste(output[!unchanged], collapse = "\n"))
