@@ -7,7 +7,9 @@ test_that("ucsc connection works", {
   skip_if_not_installed("curl")
   skip_if_not_installed("RMariaDB")
 
-  if (!has_internet()) skip("no internet connection")
+  if (!has_internet()) {
+    skip("no internet connection")
+  }
 
   skip_on_cran()
 
@@ -22,7 +24,9 @@ test_that("ensembl connection works", {
   skip_if_not_installed("curl")
   skip_if_not_installed("RMariaDB")
 
-  if (!has_internet()) skip("no internet connection")
+  if (!has_internet()) {
+    skip("no internet connection")
+  }
 
   skip_on_cran()
 
