@@ -1,11 +1,11 @@
-# fmt: skip
 x <- tibble::tribble(
-  ~chrom, ~start, ~end, ~name, ~score, ~strand,
-  "chr1", 500, 1000, ".", ".", "+",
-  "chr1", 1000, 1500, ".", ".", "-"
+  ~chrom , ~start , ~end , ~name , ~score , ~strand ,
+  "chr1" ,    500 , 1000 , "."   , "."    , "+"     ,
+  "chr1" ,   1000 , 1500 , "."   , "."    , "-"
 )
 
 test_that("glyphs are rendered", {
+  skip_on_ci()
   expect_doppelganger("merge glyph is ok", bed_glyph(bed_merge(x)))
 })
 
@@ -18,30 +18,31 @@ test_that("glyph labels are applied", {
   }
 })
 
-# fmt: skip
 a <- tibble::tribble(
-  ~chrom, ~start, ~end,
-  "chr1", 25, 50,
-  "chr1", 100, 125
+  ~chrom , ~start , ~end ,
+  "chr1" ,     25 ,   50 ,
+  "chr1" ,    100 ,  125
 )
 
-# fmt: skip
 b <- tibble::tribble(
-  ~chrom, ~start, ~end, ~value,
-  "chr1", 30, 75, 50
+  ~chrom , ~start , ~end , ~value ,
+  "chr1" ,     30 ,   75 ,     50
 )
 
 test_that("expr arguments do not need to be x and/or y", {
-  expect_doppelganger("intersect glyph is ok", bed_glyph(bed_intersect(a, b)))
+  skip_on_ci()
+  expect_doppelganger(
+    "intersect glyph is ok",
+    bed_glyph(bed_intersect(a, b, min_overlap = 0L))
+  )
 })
 
-# fmt: skip
 genome <- tibble::tribble(
-  ~chrom, ~size,
-  "chr1", 1e6
+  ~chrom , ~size ,
+  "chr1" ,   1e6
 )
 
 x <- bed_random(genome, n = 101)
 test_that("exceeding max intervals throws an error", {
-  expect_error(bed_glyph(bed_intersect(x, x)))
+  expect_error(bed_glyph(bed_intersect(x, x, min_overlap = 0L)))
 })
